@@ -17,16 +17,19 @@
 """Definition of __version__, __date__, __gitsha__.
 """
 
-from pkg_resources import resource_stream
-from ConfigParser import SafeConfigParser
+from pkg_resources import resource_filename
+from ConfigParser import RawConfigParser
 
 # obtain version information from the version.cfg file
-cp = SafeConfigParser()
-cp.readfp(resource_stream(__name__, 'version.cfg'))
+cp = RawConfigParser(dict(version='', date='', commit='', timestamp=0))
+if not cp.read(resource_filename(__name__, 'version.cfg')):
+    from warnings import warn
+    warn('Package metadata not found, execute "./setup.py egg_info".')
 
 __version__ = cp.get('DEFAULT', 'version')
 __date__ = cp.get('DEFAULT', 'date')
 __gitsha__ = cp.get('DEFAULT', 'commit')
+__timestamp__ = cp.getint('DEFAULT', 'timestamp')
 
 del cp
 
